@@ -1,7 +1,7 @@
 __all__ = ('__version__', 'Character', 'weapons', 'features',
            'character', 'race', 'background', 'spells')
 
-from dungeonsheets import background, features, race, spells, weapons
+from dungeonsheets import background, features, race, spells, weapons, mechanics
 from dungeonsheets.character import Character
 
 import os
