@@ -1,5 +1,5 @@
-from .. import (weapons, features, spells)
 from collections import defaultdict
 
+from dungeonsheets import features, spells, weapons
 
 # Custom Classes
