@@ -1,4 +1,4 @@
-from .spells import Spell
+from dungeonsheets.spells.spells import Spell
 
 
 class AbiDalzimsHorridWilting(Spell):
@@ -73,14 +73,14 @@ class AcidArrow(Spell):
 
 
 class AcidSplash(Spell):
-    """You hurl a bubble of acid.
-    Choose one creature within range, or choose two
-    creatures within range that are within 5 feet of each other. A target must
-    succeed on a Dexterity saving throw or take 1d6 acid damage.
+    """You hurl a bubble of acid.  Choose one creature within range, or
+    choose two creatures within range that are within 5 feet of each
+    other. A target must succeed on a Dexterity saving throw or take
+    1d6 acid damage.
+
+    **At Higher Levels:** This spell's damage increases by 1d6 when
+    you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).
 
-    At Higher Levels:
-    This spell's damage increases by 1d6 when you reach 5th level (2d6), 11th level
-    (3d6), and 17th level (4d6).
     """
     name = "Acid Splash"
     level = 0
@@ -95,15 +95,15 @@ class AcidSplash(Spell):
 
 
 class AganazzarsScorcher(Spell):
-    """A line of roaring flame 30 feet long and 5 feet wide emanates from you in a
-    direction you choose.
-    Each creature in the line must make a Dexterity saving
-    throw. A creature takes 3d8 fire damage on a failed save, or half as much damage
-     on a successful one.
+    """A line of roaring flame 30 feet long and 5 feet wide emanates from
+    you in a direction you choose.  Each creature in the line must
+    make a Dexterity saving throw. A creature takes 3d8 fire damage on
+    a failed save, or half as much damage on a successful one.
+
+    **At Higher Levels:** When you cast this spell using a spell slot
+    of 3rd level or higher, the damage increases by 1d8 for each slot
+    level above 2nd.
 
-    At Higher Levels: When you cast this spell using a spell
-    slot of 3rd level or higher, the damage increases by 1d8 for each slot level
-    above 2nd.
     """
     name = "Aganazzars Scorcher"
     level = 2
@@ -340,35 +340,38 @@ class AnimateDead(Spell):
 
 
 class AnimateObjects(Spell):
-    """Objects come to life at your command.
-    Choose up to ten nonmagical objects
-    within range that are not being worn or carried. Medium targets count as two
-    objects, Large targets count as four objects, Huge targets count as eight
-    objects. You can't animate any object larger than Huge. Each target animates and
-     becomes a creature under your control until the spell ends or until reduced to
-    0 hit points.
+    """Objects come to life at your command. Choose up to ten nonmagical
+    objects within range that are not being worn or carried. Medium
+    targets count as two objects, Large targets count as four objects,
+    Huge targets count as eight objects. You can't animate any object
+    larger than Huge. Each target animates and becomes a creature
+    under your control until the spell ends or until reduced to 0 hit
+    points.
 
-    As a bonus action, you can mentally command any creature you
-    made with this spell if the creature is within 500 feet of you (if you control
-    multiple creatures, you can command any or all of them at the same time, issuing
-     the same command to each one). You decide what action the creature will take
-    and where it will move during its next turn, or you can issue a general command,
-     such as to guard a particular chamber or corridor. If you issue no commands,
-    the creature only defends itself against hostile creatures. Once given an order,
-     the creature continues to follow it until its task is complete.
+    As a bonus action, you can mentally command any creature you made
+    with this spell if the creature is within 500 feet of you (if you
+    control multiple creatures, you can command any or all of them at
+    the same time, issuing the same command to each one). You decide
+    what action the creature will take and where it will move during
+    its next turn, or you can issue a general command, such as to
+    guard a particular chamber or corridor. If you issue no commands,
+    the creature only defends itself against hostile creatures. Once
+    given an order, the creature continues to follow it until its task
+    is complete.
 
-    Animated
-    Object Statistics
-    Tiny – HP: 20, AC: 18, Attack: +8 to hit, 1d4 + 4 damage,
-    Str: 4, Dex: 18
-    Small – HP: 25, AC: 16, Attack: +6 to hit, 1d8 + 2 damage, Str:
-     6, Dex: 14
-    Medium – HP: 40, AC: 13, Attack: +5 to hit, 2d6 + 1 damage, Str:
-    10, Dex: 12
-    Large – HP: 50, AC: 10, Attack: +6 to hit, 2d10 + 2 damage, Str:
-    14, Dex: 10
-    Huge – HP: 80, AC: 10, Attack: +8 to hit, 2d12 + 4 damage, Str: 18,
-     Dex: 6
+    Animated Object Statistics
+    --------------------------
+    
+    - Tiny -- HP: 20, AC: 18, Attack: +8 to hit, 1d4 + 4 damage, Str:
+      4, Dex: 18
+    - Small -- HP: 25, AC: 16, Attack: +6 to hit, 1d8 + 2 damage, Str:
+      6, Dex: 14
+    - Medium – HP: 40, AC: 13, Attack: +5 to hit, 2d6 + 1 damage, Str:
+      10, Dex: 12
+    - Large – HP: 50, AC: 10, Attack: +6 to hit, 2d10 + 2 damage, Str:
+      14, Dex: 10
+    - Huge – HP: 80, AC: 10, Attack: +8 to hit, 2d12 + 4 damage, Str:
+      18, Dex: 6
 
     An animated object is a construct with AC, hit points, attacks,
     Strength, and Dexterity determine by its size. Its Constitution is 10 and its
@@ -389,6 +392,7 @@ class AnimateObjects(Spell):
     At Higher
     Levels: If you cast this spell using a spell slot of 6th level or higher, you
     can animate two additional objects for each slot level above 5th.
+
     """
     name = "Animate Objects"
     level = 5
@@ -846,4 +850,3 @@ class Awaken(Spell):
     magic_school = "Transmutation"
     classes = ('Bard', 'Druid')
 
-
