@@ -184,14 +184,16 @@ class MagicJar(Spell):
 
 
 class MagicMissile(Spell):
-    """You create three glowing darts of magical force. Each dart hits a creature of
-    your choice that you can see within range. A dart deals 1d4 + 1 force damage to
-    its target. The darts all strike simultaneously and you can direct them to hit
-    one creature or several.
-
-    At Higher Levels: When you cast this spell using a
-    spell slot of 2nd level or higher, the spell creates one more dart for each slot
-     level above 1st.
+    """You create three glowing darts of magical force. Each dart hits a
+    creature of your choice that you can see within range. A dart
+    deals 1d4 + 1 force damage to its target. The darts all strike
+    simultaneously and you can direct them to hit one creature or
+    several.
+    
+    At Higher Levels: When you cast this spell using a spell slot of
+    2nd level or higher, the spell creates one more dart for each slot
+    level above 1st.
+    
     """
     name = "Magic Missile"
     level = 1
@@ -775,6 +777,27 @@ class MindBlank(Spell):
     classes = ('Bard', 'Wizard')
 
 
+class MindSliver(Spell):
+    """You drive a disorienting spike of psychic energy into the mind of one
+    creature you can see within range. The target must succeed on
+    an Intelligence saving throw or take 1d6 psychic damage and subtract 1d4
+    from the next saving throw it makes before the end of your next turn.
+
+    At Higher Levels: This spell’s damage increases by 1d6 when you reach
+    certain levels: 5th level (2d6), 11th level (3d6), and 17th level (4d6).
+    """
+    name = "Mind Sliver"
+    level = 0
+    casting_time = "1 action"
+    casting_range = "60 feet"
+    components = ('V',)
+    materials = """"""
+    duration = "1 round"
+    ritual = False
+    magic_school = "Enchantment"
+    classes = ('Sorcerer', 'Warlock', 'Wizard')
+
+
 class MindSpike(Spell):
     """You reach into the mind of one creature you can see within range. The target
     must make a Wisdom saving throw, taking 3d8 psychic damage on a failed save, or
